find_indentation

Function find_indentation 

pub fn find_indentation(lines: &[String]) -> usize
Find the indentation of a block

The indentation is determined by the first line with leading whitespaces and content after the leading whitespace

If body lines are empty or none of the lines have leading whitespaces, 0 is returned