pub struct Context {
pub outer_comments: Vec<String>,
pub begin_body_lines: Vec<String>,
pub indent: usize,
pub end_body_lines: Vec<String>,
}Expand description
Context for a component
Context is used to prevent expensive cloning of the entire component tree when the children are not needed
Fields
outer_comments: Vec<String>Outer comments
begin_body_lines: Vec<String>Beginning body lines
indent: usizeIndentation of the component
end_body_lines: Vec<String>End body lines
Implementations